==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/ro_ro/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Ieșire';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Intrări';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Numele parametrului nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Parametrul câmpului nu poate fi gol.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Denumirea câmpului nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Numele câmpului nu poate fi gol.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Vă rugăm să selectați o metodă validă.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Vă rugăm să selectați un tip valid.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Evenimentul furnizat nu există.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Numărul de apelare nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Vă rugăm să introduceți un callback valid.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Un webhook de acest tip există deja cu acest callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Compania furnizată nu există.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/ro_ro/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Ieșire';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Intrări';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Numele parametrului nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Parametrul câmpului nu poate fi gol.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Denumirea câmpului nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Numele câmpului nu poate fi gol.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Vă rugăm să selectați o metodă validă.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Vă rugăm să selectați un tip valid.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Evenimentul furnizat nu există.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Numărul de apelare nu poate depăși 255 de caractere.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Vă rugăm să introduceți un callback valid.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Un webhook de acest tip există deja cu acest callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Compania furnizată nu există.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'Evenimentul furnizat nu există.';
